==> drumgizmo-0.9.9.tar.gz: drumgizmo-0.9.9/src/configparser.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            configparser.h
 *
 *  Sat Jun 29 21:55:02 CEST 2013
 *  Copyright 2013 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#ifndef __DRUMGIZMO_CONFIGPARSER_H__
#define __DRUMGIZMO_CONFIGPARSER_H__

#include <map>

#include "saxparser.h"

class ConfigParser : public SAXParser {
public:
  ConfigParser();

  void characterData(std::string &data);
  void startTag(std::string name, attr_t attr);
  void endTag(std::string name);
  std::string value(std::string name, std::string def = "");
  void parseError(char *buf, size_t len, std::string error, int lineno);

private:
  std::map<std::string, std::string> values;
  std::string *str;
};

#endif/*__DRUMGIZMO_CONFIGPARSER_H__*/

==> drumgizmo_0.9.11.orig.tar.gz: drumgizmo-0.9.11/src/configparser.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/***************************************************************************
 *            configparser.h
 *
 *  Sat Jun 29 21:55:02 CEST 2013
 *  Copyright 2013 Bent Bisballe Nyeng
 *  deva@aasimon.org
 ****************************************************************************/

/*
 *  This file is part of DrumGizmo.
 *
 *  DrumGizmo is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU Lesser General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  DrumGizmo is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public License
 *  along with DrumGizmo; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.
 */
#pragma once

#include <unordered_map>

#include "saxparser.h"

class ConfigParser
	: public SAXParser
{
public:
	ConfigParser();

	void characterData(const std::string& data) override;
	void startTag(const std::string& name, const attr_t& attr) override;
	void endTag(const std::string& name) override;
	std::string value(const std::string& name, const std::string& def = "");

private:
	std::unordered_map<std::string, std::string> values;
	std::string* str;
};
